==> waterfall-protocol-1.14-20191210.200055-25-sources.jar: net/md_5/bungee/protocol/packet/Chat.java <==
package net.md_5.bungee.protocol.packet;

import io.netty.buffer.ByteBuf;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import net.md_5.bungee.protocol.AbstractPacketHandler;
import net.md_5.bungee.protocol.DefinedPacket;
import net.md_5.bungee.protocol.ProtocolConstants;

@Data
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = false)
public class Chat extends DefinedPacket
{

    private String message;
    private byte position;

    public Chat(String message)
    {
        this( message, (byte) 0 );
    }

    @Override
    public void read(ByteBuf buf, ProtocolConstants.Direction direction, int protocolVersion)
    {
        // Waterfall start
        if (direction == ProtocolConstants.Direction.TO_CLIENT) {
            this.message = readString(buf, Short.MAX_VALUE * 8 + 8);
        } else
        // Waterfall end
        message = readString( buf );
        if ( direction == ProtocolConstants.Direction.TO_CLIENT )
        {
            position = buf.readByte();
        }
    }

    @Override
    public void write(ByteBuf buf, ProtocolConstants.Direction direction, int protocolVersion)
    {
        // Waterfall start
        if (direction == ProtocolConstants.Direction.TO_CLIENT) {
            writeString(this.message, Short.MAX_VALUE * 8 + 8, buf);
        } else
        // Waterfall end
        writeString( message, buf );
        if ( direction == ProtocolConstants.Direction.TO_CLIENT )
        {
            buf.writeByte( position );
        }
    }

    @Override
    public void handle(AbstractPacketHandler handler) throws Exception
    {
        handler.handle( this );
    }
}

==> waterfall-protocol-1.15-20200623.174217-37-sources.jar: net/md_5/bungee/protocol/packet/Chat.java <==
package net.md_5.bungee.protocol.packet;

import io.netty.buffer.ByteBuf;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;
import net.md_5.bungee.protocol.AbstractPacketHandler;
import net.md_5.bungee.protocol.DefinedPacket;
import net.md_5.bungee.protocol.ProtocolConstants;

import java.util.UUID; // Waterfall (1.16: 20w21a+)

@Data
@NoArgsConstructor
@AllArgsConstructor
@EqualsAndHashCode(callSuper = false)
public class Chat extends DefinedPacket
{

    private String message;
    private byte position;
    private UUID sender; // Waterfall (1.16: 20w21a+)

    // Waterfall (1.16+ retain API)
    public Chat(String message, byte position)
    {
        this( message, position, /* Waterfall (1.16: 20w21a+) */ new UUID( 0, 0 ) );
    }

    public Chat(String message)
    {
        this( message, (byte) 0, /* Waterfall (1.16: 20w21a+) */ new UUID( 0, 0 ) );
    }

    @Override
    public void read(ByteBuf buf, ProtocolConstants.Direction direction, int protocolVersion)
    {
        // Waterfall start
        if (direction == ProtocolConstants.Direction.TO_CLIENT) {
            this.message = readString(buf, Short.MAX_VALUE * 8 + 8);
        } else
        // Waterfall end
        message = readString( buf );
        if ( direction == ProtocolConstants.Direction.TO_CLIENT )
        {
            position = buf.readByte();
            // Waterfall (1.16: 20w21a+) start:
            if( protocolVersion >= ProtocolConstants.MINECRAFT_1_16 )
            {
                sender = new UUID( buf.readLong(), buf.readLong() );
            }
            // Waterfall end
        }
    }

    @Override
    public void write(ByteBuf buf, ProtocolConstants.Direction direction, int protocolVersion)
    {
        // Waterfall start
        if (direction == ProtocolConstants.Direction.TO_CLIENT) {
            writeString(this.message, Short.MAX_VALUE * 8 + 8, buf);
        } else
        // Waterfall end
        writeString( message, buf );
        if ( direction == ProtocolConstants.Direction.TO_CLIENT )
        {
            buf.writeByte( position );
            // Waterfall (1.16: 20w21a+) start:
            if( protocolVersion >= ProtocolConstants.MINECRAFT_1_16 )
            {
                buf.writeLong( sender.getMostSignificantBits() );
                buf.writeLong( sender.getLeastSignificantBits() );
            }
            // Waterfall end
        }
    }

    @Override
    public void handle(AbstractPacketHandler handler) throws Exception
    {
        handler.handle( this );
    }
}
